(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     56175,       1578]*)
(*NotebookOutlinePosition[     57170,       1611]*)
(*  CellTagsIndexPosition[     57126,       1607]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Groundwater response to tidal fluctuation in a leaky confined aquifer using \
Jiao & Tang solution\
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Xiaoyong Zhan\n",
  ButtonBox["xyz@ku.edu",
    ButtonData:>{
      URL[ "mailto:xyz@ku.edu"], None},
    ButtonStyle->"Hyperlink"]
}], "Author"],

Cell[CellGroupData[{

Cell["Needs", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(Off[General::"\<spell1\>"];\), 
      " "}], "\[IndentingNewLine]", \(Needs["\<Graphics`Master`\>"]\), "\
\[IndentingNewLine]", \(nbInf = \[InvisibleSpace]NotebookInformation[
          EvaluationNotebook[]];\), "\[IndentingNewLine]", \(thisFile = 
        StringDrop[
          ToFileName[\(("\<FileName\>" /. 
                  nbInf)\)\[LeftDoubleBracket]2\[RightDoubleBracket]], \
\(-1\)];\), "\n", \(SetDirectory[
        ToFileName[\(("\<FileName\>" /. 
                nbInf)\)\[LeftDoubleBracket]1\[RightDoubleBracket]]];\), "\n\
", \(modDate = FileDate[thisFile];\), "\n", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<Notebook: \>\"", ",", 
          RowBox[{
            StyleBox["Directory",
              "MR"], 
            StyleBox["[",
              "MR"], " ", 
            StyleBox["]",
              "MR"]}], " ", ",", "\"\<\\\\\>\"", ",", "thisFile", ",", 
          "\"\<\\nLast modified: \>\"", 
          ",", \(modDate\[LeftDoubleBracket]2\[RightDoubleBracket]\), ",", 
          "\"\</ \>\"", 
          ",", \(modDate\[LeftDoubleBracket]3\[RightDoubleBracket]\), ",", 
          "\"\< /\>\"", 
          ",", \(modDate\[LeftDoubleBracket]1\[RightDoubleBracket]\), ",", 
          "\"\< \>\"", 
          ",", \(modDate\[LeftDoubleBracket]4\[RightDoubleBracket]\), ",", 
          "\"\<:\>\"", 
          ",", \(modDate\[LeftDoubleBracket]5\[RightDoubleBracket]\)}], "]"}],
       ";"}]}], "Input",
  PageWidth->WindowWidth,
  TextJustification->0,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("Notebook: \
"\[InvisibleSpace]"E:\\Mathematica\\JiaoTang1999"\[InvisibleSpace]"\\"\
\[InvisibleSpace]"xyz2.nb"\[InvisibleSpace]"\nLast modified: "\
\[InvisibleSpace]9\[InvisibleSpace]"/ "\[InvisibleSpace]8\[InvisibleSpace]" \
/"\[InvisibleSpace]2003\[InvisibleSpace]" "\[InvisibleSpace]12\
\[InvisibleSpace]":"\[InvisibleSpace]4\),
      SequenceForm[ 
      "Notebook: ", "E:\\Mathematica\\JiaoTang1999", "\\", "xyz2.nb", 
        "\nLast modified: ", 9, "/ ", 8, " /", 2003, " ", 12, ":", 4],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Time and Memory Info at Start ", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Print[\ \ {{"\<Time used in Seconds:  \>", 
              NumberForm[TimeUsed[]]}, \ {"\<Memory Used in Mb: \>", 
              NumberForm[\(MemoryInUse[]/1024. \)/1024. ]}} // 
          TableForm];\)\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"Time used in Seconds:  \"\>", 
            TagBox[
              InterpretationBox["\<\"0.05\"\>",
                .049999999999999989,
                AutoDelete->True],
              NumberForm]},
          {"\<\"Memory Used in Mb: \"\>", 
            TagBox[
              InterpretationBox["\<\"2.09363\"\>",
                2.0936279296875,
                AutoDelete->True],
              NumberForm]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input data", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(\( (*\ 
      Data\ for\ Groundwater\ fluctuation\ at\ Hong\ Kong\ CLK\ airport\ \
*) \)\(\[IndentingNewLine]\)\(TdS = 4.4\[Times]\ 10\^3; \  (*\ T/S[m\^2/h]; \ 
      T\ transmissivity; \ S\ storativity\ *) \n
    TdL = 9.2\[Times]\ 10\^5; \  (*\ T/L[m\^2]; \ 
      L\ leakance\ or\ specific\ leakage\ *) \n
    A = 0.8; \  (*\ 
      amplitude\ of\ tidal\ change\ [
          m]\ *) \n\[Omega] = \(2\ \[Pi]\)\/12.2; \  (*\ 
      tidal\ speed\ [1/h]\ *) \nc = 0\ ;  (*\ phase\ shift\ [h]\ *) \n
    x = 271\ ; \  (*\ distant\ [m]\ *) \[IndentingNewLine]p = 
      Sqrt[1\/2]\ Sqrt[
          1\/TdL + Sqrt[\((1\/TdL)\)\^2 + \((\[Omega]\/TdS)\)\^2]]; \  (*\ 
      defined\ working\ variable\ *) \[IndentingNewLine]\(\(\(t\_\[Tau]\  = \ 
        x\/\(2\ p\ TdS\)\)\(\ \)\)\(;\)\(\ \ \)\( (*\ 
      defined\ working\ variable\ *) \)\(\[IndentingNewLine]\)\)\)\)\)], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Result", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Evaluate[A\ Exp[\(-p\)\ \ x\ ]\ \ Cos[\[Omega]\ t\ \  - \ 
              t\_\[Tau]\ \[Omega]\  + c]], {t, 0, 30}, 
      PlotRange \[Rule] {\(-0.1\), 0.1}, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Time(hr)\>", "\<Groundwater level(m)\>"}, 
      PlotLabel \[Rule] 
        StringJoin["\<Groundwater fluctuation at Hong Kong CLK airport\>", \
"\< \>"], PlotRange \[Rule] All, GridLines \[Rule] {None, None}, 
      PlotStyle \[Rule] {PointSize[0.01]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.309017 3.09017 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .07725 -36 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -30 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -36 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -30 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -24 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -30 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -48.5625 -62 ]
[-0.01875 .30902 -36 62 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -149 0 ]
[.5 .63053 149 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 12.813 moveto
(H) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(hr) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 12.813 moveto
(L) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(-0.075)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.05)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.025)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.025)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.05)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.075)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -165.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
123 10.2813 translate
90 rotate
-123 -10.2813 translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Groundwater) show
135.000 12.813 moveto
(level) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
165.000 12.813 moveto
(H) show
171.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
177.000 12.813 moveto
(L) show
183.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
gsave
.5 .63053 -210 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Groundwater) show
135.000 12.813 moveto
(fluctuation) show
207.000 12.813 moveto
(at) show
225.000 12.813 moveto
(Hong) show
255.000 12.813 moveto
(Kong) show
285.000 12.813 moveto
(CLK) show
309.000 12.813 moveto
(airport) show
357.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .16332 m
.06244 .35016 L
.08255 .4458 L
.0932 .49117 L
.10458 .53367 L
.11531 .56675 L
.12507 .59011 L
.12977 .59889 L
.13488 .6065 L
.13722 .60931 L
.1397 .61182 L
.14183 .61358 L
.14415 .61508 L
.14546 .61574 L
.14667 .61622 L
.14783 .61658 L
.14907 .61683 L
.15028 .61697 L
.15142 .61698 L
.15245 .6169 L
.15356 .61672 L
.15479 .61641 L
.15613 .61593 L
.15753 .61527 L
.15884 .61451 L
.16118 .61281 L
.16369 .6105 L
.1686 .60453 L
.17326 .59714 L
.18199 .57891 L
.19164 .55247 L
.2019 .51788 L
.22032 .44199 L
.25807 .25814 L
.27904 .15969 L
.29827 .08423 L
.30803 .05384 L
.31712 .03129 L
.32208 .02148 L
.32659 .01418 L
.3316 .00793 L
.33436 .00534 L
.33696 .00345 L
.33811 .00278 L
.33935 .00219 L
.34042 .00178 L
.34159 .00143 L
.3423 .00127 L
.34295 .00116 L
.34425 .00105 L
Mistroke
.34543 .00107 L
.34668 .00121 L
.34738 .00134 L
.34802 .0015 L
.34946 .00198 L
.35074 .00254 L
.35208 .00327 L
.35441 .00489 L
.35697 .00717 L
.36158 .01258 L
.36652 .02021 L
.37542 .03861 L
.38562 .06658 L
.3967 .10444 L
.41684 .18912 L
.45767 .38895 L
.47796 .48081 L
.4879 .51959 L
.49699 .55034 L
.50569 .57486 L
.51519 .59558 L
.52015 .60371 L
.52475 .60956 L
.52725 .61204 L
.52961 .61392 L
.53091 .61477 L
.53233 .61554 L
.53362 .61609 L
.53479 .61649 L
.53601 .61677 L
.53716 .61693 L
.53838 .61699 L
.53906 .61696 L
.5397 .61691 L
.54075 .61675 L
.54192 .61646 L
.54314 .61604 L
.54428 .61554 L
.5469 .61401 L
.5493 .61211 L
.55471 .60616 L
.5596 .5988 L
.56496 .58865 L
.57576 .56187 L
.59535 .49428 L
.61629 .40171 L
.65776 .19852 L
.67854 .10967 L
.68766 .07722 L
.69771 .04739 L
Mistroke
.70235 .0359 L
.70734 .02528 L
.71166 .0176 L
.71637 .01085 L
.71912 .00771 L
.72166 .00533 L
.7241 .00355 L
.72535 .00282 L
.7267 .00217 L
.72803 .00167 L
.72925 .00134 L
.73042 .00114 L
.73165 .00105 L
.73276 .00107 L
.73379 .00118 L
.73493 .0014 L
.73614 .00175 L
.73736 .00223 L
.73871 .00289 L
.74143 .00467 L
.74396 .00686 L
.74633 .00937 L
.75165 .01663 L
.7574 .02689 L
.7679 .05192 L
.77752 .08141 L
.81717 .2513 L
.8553 .43741 L
.87656 .52452 L
.88661 .55737 L
.89588 .58184 L
.90552 .60077 L
.9106 .6079 L
.91319 .61076 L
.91598 .61323 L
.91842 .61489 L
.92064 .61599 L
.92172 .61637 L
.92288 .61669 L
.92399 .61688 L
.92501 .61697 L
.92631 .61697 L
.92753 .61684 L
.92863 .61662 L
.92982 .61627 L
.93112 .61576 L
.93249 .61507 L
.93494 .61347 L
.9375 .61128 L
.93992 .60873 L
Mistroke
.94445 .60271 L
.94933 .59446 L
.95463 .58348 L
.97299 .53043 L
.97619 .51901 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{399.438, 246.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006?0000mQ000`40O003h00OogooT7oo003oOon@
Ool00>Ioo`03001oogoo00aoo`03001oogoo09Moo`00iGoo00<007ooOol03Woo00<007ooOol0UWoo
003;Ool30004Ool300001goo000007oo001oo`00009oo`<000=oo`04001oogooOol3000017oo0000
07oo100017oo00<007ooOol0UGoo003<Ool00`00Oomoo`04Ool02`00Oomoogoo001oo`00Ool007oo
00001Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo09Eoo`00c7oo
00<007ooOol017oo00X007ooOomoo`00Ool007oo001oo`@000=oo`03001oogoo009oo`04001oogoo
0003Ool00`00Oomoo`04Ool00`00Oomoo`2EOol00<aoo`03001oogoo00=oo`80009oo`<00003Ool0
07oo009oo`8000Aoo`03001oogoo009oo`<000=oo`@000Aoo`03001oogoo09Eoo`00bWoo00D007oo
001oo`0001Ioo`05001oogooOol0000<Ool00`00Oomoo`2FOol00<Yoo`D000Aoo`03001oogoo011o
o`04001oo`00000;Ool00`00Oomoo`2GOol00?mooi1oo`00ogooT7oo003oOon@Ool004Aoo`80039o
o`8002moo`D0009oo`8002]oo`D0009oo`8002]oo`@000=oo`8002aoo`@000=oo`8002aoo`8000Ao
o`8000aoo`00@goo00@007ooOol0031oo`04001oogoo000`Ool01@00Oomoogoo00000Woo00<007oo
Ool0:Woo00D007ooOomoo`00009oo`03001oogoo02Qoo`03001oogoo00=oo`04001oogoo000[Ool0
0`00Oomoo`03Ool01000Oomoo`00:Woo00@007ooOol0009oo`04001oogoo000;Ool004=oo`04001o
ogoo000cOol00`00Oomoo`0^Ool01@00Oomoogoo00000Woo00<007ooOol0:Woo00<007ooOol017oo
00<007ooOol0:Goo00<007ooOol00Woo00@007ooOol002aoo`03001oogoo00Eoo`03001oogoo02Yo
o`05001oogooOol00002Ool00`00Oomoo`09Ool004=oo`04001oogoo000aOol2000aOol01@00Oomo
ogoo00000Woo00<007ooOol0:Woo00<007ooOol00Woo0P00;Goo00D007ooOomoo`00009oo`03001o
ogoo02]oo`03001oogoo009oo`8002ioo`04001oogoo0002Ool00`00Oomoo`09Ool004=oo`04001o
ogoo000aOol00`00Oomoo`0`Ool01@00Oomoogoo00000Woo00<007ooOol0:Woo00<007ooOol00Woo
00<007ooOol0:Woo00@007ooOol0009oo`04001oogoo000[Ool01000Oomoo`000goo00<007ooOol0
:Woo00@007ooOol0009oo`04001oogoo000;Ool004Aoo`80039oo`<002moo`8000Aoo`8002aoo`80
00Aoo`<002]oo`8000Aoo`8002eoo`8000Aoo`<002]oo`8000Aoo`8000aoo`00ogooT7oo003oOon@
Ool00?mooi1oo`00ogooT7oo003oOon@Ool00?mooi1oo`00?Gooo`00C0001goo000mOol00`00Oomo
o`05Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool60006Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool70004Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool003eoo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Eoo`04001oogoo0003Ool00`00Oomoo`03Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`04Ool01@00Oomoogoo00002Goo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
1Goo00<007ooOol01Goo000mOol00`00Oomoo`1[Ool00`00Oomoo`05Ool00`00Oomoo`1dOol00`00
Oomoo`05Ool2001COol00`00Oomoo`05Ool003eoo`03001oogoo06Yoo`03001oogoo00Moo`03001o
ogoo079oo`03001oogoo00Qoo`03001oogoo051oo`03001oogoo00Eoo`00?Goo0`00JGoo00<007oo
Ool02Goo00<007ooOol0L7oo00<007ooOol02Goo00<007ooOol0CWoo0`001goo000mOol00`00Oomo
o`1XOol00`00Oomoo`0:Ool00`00Oomoo`1`Ool00`00Oomoo`0:Ool00`00Oomoo`1?Ool00`00Oomo
o`05Ool003eoo`03001oogoo06Moo`03001oogoo00aoo`03001oogoo06ioo`03001oogoo00aoo`03
001oogoo04ioo`03001oogoo00Eoo`00?Goo00<007ooOol0Igoo00<007ooOol037oo00<007ooOol0
KWoo00<007ooOol037oo00<007ooOol0CWoo00<007ooOol01Goo000mOol00`00Oomoo`1VOol00`00
Oomoo`0>Ool00`00Oomoo`1/Ool00`00Oomoo`0>Ool00`00Oomoo`1=Ool00`00Oomoo`05Ool003eo
o`<006Ioo`03001oogoo00ioo`03001oogoo06aoo`03001oogoo00ioo`03001oogoo04]oo`<000Mo
o`00?Goo00<007ooOol0IWoo00<007ooOol03goo00<007ooOol0JWoo00<007ooOol047oo00<007oo
Ool0C7oo00<007ooOol01Goo000mOol00`00Oomoo`1VOol00`00Oomoo`0?Ool00`00Oomoo`1ZOol0
0`00Oomoo`0@Ool00`00Oomoo`1<Ool00`00Oomoo`05Ool003eoo`03001oogoo06Eoo`03001oogoo
015oo`03001oogoo06Qoo`03001oogoo015oo`03001oogoo04aoo`03001oogoo00Eoo`00?Goo00<0
07ooOol0IGoo00<007ooOol04Goo00<007ooOol0J7oo00<007ooOol04Woo00<007ooOol0Bgoo00<0
07ooOol01Goo000mOol00`00Oomoo`1TOol00`00Oomoo`0COol00`00Oomoo`1VOol00`00Oomoo`0C
Ool00`00Oomoo`1;Ool00`00Oomoo`05Ool003eoo`<006Aoo`03001oogoo01=oo`03001oogoo06Io
o`03001oogoo01Aoo`03001oogoo04Qoo`<000Moo`00?Goo00<007ooOol0Hgoo00<007ooOol057oo
00<007ooOol0IWoo00<007ooOol057oo00<007ooOol0BWoo00<007ooOol01Goo000mOol00`00Oomo
o`1SOol00`00Oomoo`0EOol00`00Oomoo`1TOol00`00Oomoo`0EOol00`00Oomoo`1:Ool00`00Oomo
o`05Ool003eoo`03001oogoo06=oo`03001oogoo01Eoo`03001oogoo06Aoo`03001oogoo01Ioo`03
001oogoo04Uoo`03001oogoo00Eoo`00?Goo00<007ooOol0HWoo00<007ooOol05Woo00<007ooOol0
I7oo00<007ooOol05Woo00<007ooOol0BGoo00<007ooOol01Goo000mOol3001ROol00`00Oomoo`0G
Ool00`00Oomoo`1ROol00`00Oomoo`0GOol00`00Oomoo`17Ool30007Ool003eoo`03001oogoo069o
o`03001oogoo01Moo`03001oogoo069oo`03001oogoo01Moo`03001oogoo04Uoo`03001oogoo00Eo
o`00?Goo00<007ooOol0HGoo00<007ooOol067oo00<007ooOol0HWoo00<007ooOol067oo00<007oo
Ool0B7oo00<007ooOol01Goo000MOol20004Ool20004Ool20005Ool00`00Oomoo`02Ool20006Ool0
0`00Oomoo`1QOol00`00Oomoo`0IOol00`00Oomoo`1QOol00`00Oomoo`0HOol00`00Oomoo`18Ool0
0`00Oomoo`05Ool001aoo`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`03
001oogoo00=oo`03001oogoo065oo`03001oogoo01Uoo`03001oogoo061oo`03001oogoo01Uoo`03
001oogoo04Qoo`03001oogoo00Eoo`0077oo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool3001QOol00`00Oomoo`0IOol00`00Oomoo`1POol00`00Oomoo`0JOol0
0`00Oomoo`15Ool30007Ool001Ioo`@0009oo`04001oogoo0008Ool01000Oomoo`001Goo00@007oo
Oomoo`8000Ioo`03001oogoo061oo`03001oogoo01]oo`03001oogoo05moo`03001oogoo01Yoo`03
001oogoo04Moo`03001oogoo00Eoo`0077oo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol01Goo00<007ooOol0H7oo00<007ooOol06goo00<007ooOol0GWoo00<007oo
Ool06goo00<007ooOol0Agoo00<007ooOol01Goo000MOol2000:Ool20003Ool40003Ool30005Ool0
0`00Oomoo`1POol00`00Oomoo`0KOol00`00Oomoo`1NOol00`00Oomoo`0KOol00`00Oomoo`17Ool0
0`00Oomoo`05Ool003eoo`03001oogoo05moo`03001oogoo01aoo`03001oogoo05ioo`03001oogoo
01aoo`03001oogoo04Ioo`03001oogoo00Eoo`00?Goo0`00Ggoo00<007ooOol07Goo00<007ooOol0
G7oo00<007ooOol07Goo00<007ooOol0A7oo0`001goo000mOol00`00Oomoo`1OOol00`00Oomoo`0M
Ool00`00Oomoo`1LOol00`00Oomoo`0MOol00`00Oomoo`16Ool00`00Oomoo`05Ool003eoo`03001o
ogoo05moo`03001oogoo01eoo`03001oogoo05aoo`03001oogoo01eoo`03001oogoo04Ioo`03001o
ogoo00Eoo`00?Goo00<007ooOol0GWoo00<007ooOol07goo00<007ooOol0Fgoo00<007ooOol07Woo
00<007ooOol0AGoo00<007ooOol01Goo000mOol00`00Oomoo`1NOol00`00Oomoo`0OOol00`00Oomo
o`1JOol00`00Oomoo`0OOol00`00Oomoo`15Ool00`00Oomoo`05Ool003eoo`<005ioo`03001oogoo
01moo`03001oogoo05Yoo`03001oogoo01moo`03001oogoo04=oo`<000Moo`00?Goo00<007ooOol0
GGoo00<007ooOol087oo00<007ooOol0FWoo00<007ooOol07goo00<007ooOol0AGoo00<007ooOol0
1Goo000mOol00`00Oomoo`1MOol00`00Oomoo`0QOol00`00Oomoo`1IOol00`00Oomoo`0POol00`00
Oomoo`14Ool00`00Oomoo`05Ool003eoo`03001oogoo05eoo`03001oogoo025oo`03001oogoo05Qo
o`03001oogoo025oo`03001oogoo04Aoo`03001oogoo00Eoo`00?Goo00<007ooOol0GGoo00<007oo
Ool08Goo00<007ooOol0F7oo00<007ooOol08Goo00<007ooOol0A7oo00<007ooOol01Goo000mOol3
001LOol00`00Oomoo`0ROol00`00Oomoo`1HOol00`00Oomoo`0QOol00`00Oomoo`12Ool30007Ool0
03eoo`03001oogoo05aoo`03001oogoo02=oo`03001oogoo05Moo`03001oogoo025oo`03001oogoo
04Aoo`03001oogoo00Eoo`00?Goo00<007ooOol0G7oo00<007ooOol08goo00<007ooOol0EWoo00<0
07ooOol08goo00<007ooOol0@goo00<007ooOol01Goo000:Ool4000_Ool00`00Oomoo`1LOol00`00
Oomoo`0SOol00`00Oomoo`1FOol00`00Oomoo`0SOol00`00Oomoo`13Ool00`00Oomoo`05Ool000Uo
o`03001oogoo009oo`03001oogoo02aoo`03001oogoo05]oo`03001oogoo02Aoo`03001oogoo05Io
o`03001oogoo02=oo`03001oogoo04=oo`03001oogoo00Eoo`002Goo00H007ooOol007oo000^Ool3
001KOol00`00Oomoo`0UOol00`00Oomoo`1EOol00`00Oomoo`0SOol00`00Oomoo`11Ool30007Ool0
00Uoo`03001oogoo008002moo`03001oogoo05]oo`03001oogoo02Eoo`03001oogoo05Aoo`03001o
ogoo02Eoo`03001oogoo049oo`03001oogoo00Eoo`0037oo00<007ooOol0;Woo00<007ooOol0FWoo
00<007ooOol09Woo00<007ooOol0E7oo00<007ooOol09Goo00<007ooOol0@Woo00<007ooOol01Goo
000SOol20004Ool20004Ool20004Ool20006Ool00`00Oomoo`1JOol00`00Oomoo`0VOol00`00Oomo
o`1DOol00`00Oomoo`0UOol00`00Oomoo`12Ool00`00Oomoo`05Ool000]oo`04001oogoo000COol0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`1JOol00`00Oomoo`0W
Ool00`00Oomoo`1COol00`00Oomoo`0UOol00`00Oomoo`12Ool00`00Oomoo`05Ool000]oo`@001=o
o`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol00goo0`00FWoo00<007ooOol09goo00<0
07ooOol0DWoo00<007ooOol09goo00<007ooOol0?goo0`001goo000;Ool01000Oomoo`003Goo1000
0Woo00@007ooOol000Qoo`04001oogoo0003Ool20006Ool00`00Oomoo`1IOol00`00Oomoo`0XOol0
0`00Oomoo`1BOol00`00Oomoo`0WOol00`00Oomoo`11Ool00`00Oomoo`05Ool000]oo`04001oogoo
000COol01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo05Uoo`03001o
ogoo02Qoo`03001oogoo059oo`03001oogoo02Moo`03001oogoo045oo`03001oogoo00Eoo`008goo
0P002Woo0P0017oo0`001Goo00<007ooOol01Goo00<007ooOol0DGoo00<007ooOol0:Goo00<007oo
Ool0DGoo00<007ooOol09goo00<007ooOol0@Goo00<007ooOol01Goo000mOol00`00Oomoo`05Ool0
0`00Oomoo`1AOol00`00Oomoo`0YOol00`00Oomoo`1AOol00`00Oomoo`0WOol00`00Oomoo`11Ool0
0`00Oomoo`05Ool000aoo`8002moo`<000Eoo`03001oogoo051oo`03001oogoo02Yoo`03001oogoo
051oo`03001oogoo02Uoo`03001oogoo03ioo`<000Moo`002goo00@007ooOol002ioo`03001oogoo
00Ioo`03001oogoo04moo`03001oogoo02Yoo`03001oogoo051oo`03001oogoo02Uoo`03001oogoo
041oo`03001oogoo00Eoo`002goo00@007ooOol002ioo`03001oogoo00Ioo`03001oogoo04moo`03
001oogoo02]oo`03001oogoo04moo`03001oogoo02Uoo`03001oogoo041oo`03001oogoo00Eoo`00
37oo0P00;goo00<007ooOol01Woo00<007ooOol0Cgoo00<007ooOol0:goo00<007ooOol0Cgoo00<0
07ooOol0:Goo00<007ooOol0@7oo00<007ooOol01Goo000mOol00`00Oomoo`06Ool00`00Oomoo`1>
Ool00`00Oomoo`0/Ool00`00Oomoo`1>Ool00`00Oomoo`0[Ool00`00Oomoo`0oOol00`00Oomoo`05
Ool000]oo`03001oogoo02moo`<000Ioo`03001oogoo04ioo`03001oogoo02aoo`03001oogoo04io
o`03001oogoo02]oo`03001oogoo03eoo`<000Moo`002goo0`00;goo00<007ooOol01goo00<007oo
Ool0CGoo00<007ooOol0;Goo00<007ooOol0CGoo00<007ooOol0:goo00<007ooOol0?goo00<007oo
Ool01Goo000>Ool00`00Oomoo`0/Ool00`00Oomoo`07Ool00`00Oomoo`1=Ool00`00Oomoo`0]Ool0
0`00Oomoo`1=Ool00`00Oomoo`0[Ool00`00Oomoo`0oOol00`00Oomoo`05Ool000]oo`03001oo`00
02moo`03001oogoo00Moo`03001oogoo04eoo`03001oogoo02eoo`03001oogoo04aoo`03001oogoo
02eoo`03001oogoo03ioo`03001oogoo00Eoo`002goo1000;Woo00<007ooOol01goo00<007ooOol0
C7oo00<007ooOol0;Woo00<007ooOol0C7oo00<007ooOol0;Goo00<007ooOol0?Woo00<007ooOol0
1Goo000>Ool00`00Oomoo`0/Ool30008Ool00`00Oomoo`1;Ool00`00Oomoo`0_Ool00`00Oomoo`1;
Ool00`00Oomoo`0]Ool00`00Oomoo`0lOol30007Ool000]oo`04001oogoo000^Ool00`00Oomoo`08
Ool00`00Oomoo`1;Ool00`00Oomoo`0_Ool00`00Oomoo`1;Ool00`00Oomoo`0]Ool00`00Oomoo`0n
Ool00`00Oomoo`05Ool000]oo`@002ioo`03001oogoo00Qoo`03001oogoo04]oo`03001oogoo02mo
o`03001oogoo04]oo`03001oogoo02ioo`03001oogoo03eoo`03001oogoo00Eoo`002goo00<007oo
Ool0;goo00<007ooOol027oo00<007ooOol0BWoo00<007ooOol0<7oo00<007ooOol0BWoo00<007oo
Ool0;goo00<007ooOol0?Goo00<007ooOol01Goo000;Ool00`00Oomoo`0_Ool00`00Oomoo`08Ool0
0`00Oomoo`1:Ool00`00Oomoo`0`Ool00`00Oomoo`1:Ool00`00Oomoo`0_Ool00`00Oomoo`0mOol0
0`00Oomoo`05Ool000aoo`<002ioo`03001oogoo00Uoo`03001oogoo04Uoo`03001oogoo035oo`03
001oogoo04Uoo`03001oogoo02moo`03001oogoo03eoo`03001oogoo00Eoo`003Woo00<007ooOol0
;7oo0`002Goo00<007ooOol0BGoo00<007ooOol0<Goo00<007ooOol0BGoo00<007ooOol0;goo00<0
07ooOol0>goo0`001goo000mOol00`00Oomoo`09Ool00`00Oomoo`19Ool00`00Oomoo`0aOol00`00
Oomoo`19Ool00`00Oomoo`0`Ool00`00Oomoo`0lOol00`00Oomoo`05Ool000aoo`8002moo`03001o
ogoo00Uoo`03001oogoo04Qoo`03001oogoo039oo`03001oogoo04Qoo`03001oogoo035oo`03001o
ogoo03aoo`03001oogoo00Eoo`002goo00@007ooOol000ioo`8000Aoo`8000Aoo`8000=oo`@000=o
o`8000Ioo`03001oogoo00Uoo`03001oogoo04Qoo`03001oogoo039oo`03001oogoo04Qoo`03001o
ogoo035oo`03001oogoo03aoo`03001oogoo00Eoo`002Goo00<007oo00000Woo00<007ooOol02goo
00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol0
2Woo00<007ooOol0Agoo00<007ooOol0<goo00<007ooOol0Agoo00<007ooOol0<Goo00<007ooOol0
?7oo00<007ooOol01Goo0009Ool6000=Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Eoo`03001oogoo00=oo`<000Yoo`03001oogoo04Moo`03001oogoo03=oo`03001oogoo04Moo`03
001oogoo039oo`03001oogoo03Uoo`<000Moo`003Woo00<007ooOol01Goo10000Woo00@007ooOol0
00Qoo`04001oogoo0004Ool00`00Oomoo`02Ool20006Ool00`00Oomoo`0:Ool00`00Oomoo`17Ool0
0`00Oomoo`0cOol00`00Oomoo`16Ool00`00Oomoo`0cOol00`00Oomoo`0kOol00`00Oomoo`05Ool0
00]oo`03001oogoo00ioo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
ogoo00Eoo`03001oogoo00Yoo`03001oogoo04Ioo`03001oogoo03Aoo`03001oogoo04Ioo`03001o
ogoo03=oo`03001oogoo03]oo`03001oogoo00Eoo`002goo0`003goo0P002Woo0P0017oo0P0017oo
0`001Goo00<007ooOol02Woo00<007ooOol0AWoo00<007ooOol0=7oo00<007ooOol0AWoo00<007oo
Ool0<goo00<007ooOol0>goo00<007ooOol01Goo000;Ool01000Oomoo`00;Woo00<007ooOol02goo
00<007ooOol0AGoo00<007ooOol0=Goo00<007ooOol0AGoo00<007ooOol0=7oo00<007ooOol0>Woo
00<007ooOol01Goo000<Ool2000_Ool3000;Ool00`00Oomoo`15Ool00`00Oomoo`0eOol00`00Oomo
o`15Ool00`00Oomoo`0dOol00`00Oomoo`0hOol30007Ool000]oo`04001oogoo000^Ool00`00Oomo
o`0;Ool00`00Oomoo`14Ool00`00Oomoo`0fOol00`00Oomoo`14Ool00`00Oomoo`0eOol00`00Oomo
o`0jOol00`00Oomoo`05Ool000]oo`<002moo`03001oogoo00]oo`03001oogoo04Aoo`03001oogoo
03Ioo`03001oogoo04Aoo`03001oogoo03Eoo`03001oogoo03Yoo`03001oogoo00Eoo`00?Goo00<0
07ooOol02goo00<007ooOol0A7oo00<007ooOol0=Woo00<007ooOol0A7oo00<007ooOol0=Goo00<0
07ooOol0>Woo00<007ooOol01Goo000=Ool2000^Ool00`00Oomoo`0<Ool00`00Oomoo`13Ool00`00
Oomoo`0gOol00`00Oomoo`13Ool00`00Oomoo`0fOol00`00Oomoo`0iOol00`00Oomoo`05Ool000]o
o`04001oo`00000^Ool3000<Ool00`00Oomoo`13Ool00`00Oomoo`0gOol00`00Oomoo`13Ool00`00
Oomoo`0fOol00`00Oomoo`0gOol30007Ool000]oo`04001oo`00000^Ool00`00Oomoo`0<Ool00`00
Oomoo`12Ool00`00Oomoo`0hOol00`00Oomoo`12Ool00`00Oomoo`0gOol00`00Oomoo`0iOol00`00
Oomoo`05Ool000]oo`@002ioo`03001oogoo00aoo`03001oogoo049oo`03001oogoo03Qoo`03001o
ogoo049oo`03001oogoo03Moo`03001oogoo03Uoo`03001oogoo00Eoo`003Woo00<007ooOol0;7oo
00<007ooOol03Goo00<007ooOol0@Goo00<007ooOol0>7oo00<007ooOol0@Woo00<007ooOol0=goo
00<007ooOol0>Goo00<007ooOol01Goo000;Ool00`00Oomoo`0_Ool00`00Oomoo`0=Ool00`00Oomo
o`11Ool00`00Oomoo`0iOol00`00Oomoo`11Ool00`00Oomoo`0hOol00`00Oomoo`0hOol00`00Oomo
o`05Ool000Yoo`@002moo`<000eoo`03001oogoo045oo`03001oogoo03Uoo`03001oogoo045oo`03
001oogoo03Qoo`03001oogoo03Ioo`<000Moo`002goo00@007ooOol002ioo`03001oogoo00eoo`03
001oogoo041oo`03001oogoo03Yoo`03001oogoo041oo`03001oogoo03Uoo`03001oogoo03Qoo`03
001oogoo00Eoo`002goo00@007ooOol002ioo`03001oogoo00eoo`03001oogoo041oo`03001oogoo
03Yoo`03001oogoo041oo`03001oogoo03Uoo`03001oogoo03Qoo`03001oogoo00Eoo`002goo00<0
07oo0000;goo00<007ooOol03Woo00<007ooOol0?goo00<007ooOol0>Woo00<007ooOol0@7oo00<0
07ooOol0>Woo00<007ooOol0=goo00<007ooOol01Goo000mOol00`00Oomoo`0>Ool00`00Oomoo`0o
Ool00`00Oomoo`0kOol00`00Oomoo`0oOol00`00Oomoo`0jOol00`00Oomoo`0gOol00`00Oomoo`05
Ool003eoo`<000ioo`03001oogoo03moo`03001oogoo03]oo`03001oogoo03moo`03001oogoo03Yo
o`03001oogoo03Eoo`<000Moo`0037oo0P00;goo00<007ooOol03Woo00<007ooOol0?Woo00<007oo
Ool0?7oo00<007ooOol0?Woo00<007ooOol0>goo00<007ooOol0=goo00<007ooOol01Goo000;Ool2
00000goo001oo`0]Ool00`00Oomoo`0>Ool00`00Oomoo`0nOol00`00Oomoo`0lOol00`00Oomoo`0n
Ool00`00Oomoo`0kOol00`00Oomoo`0gOol00`00Oomoo`05Ool000]oo`800003Ool007oo02Eoo`80
00Ioo`03001oogoo00moo`03001oogoo03eoo`03001oogoo03aoo`03001oogoo03ioo`03001oogoo
03aoo`03001oogoo03Ioo`03001oogoo00Eoo`0037oo00<007oo00009Goo00@007ooOol000Eoo`03
001oogoo00moo`03001oogoo03eoo`03001oogoo03eoo`03001oogoo03eoo`03001oogoo03aoo`03
001oogoo03Ioo`03001oogoo00Eoo`00=7oo00@007ooOol000Eoool004`000Moo`00=7oo00@007oo
Ool000Eoo`03001oogoo00moo`03001oogoo03aoo`03001oogoo03ioo`03001oogoo03aoo`03001o
ogoo03eoo`03001oogoo03Ioo`03001oogoo00Eoo`002goo00@007ooOol002Eoo`04001oogoo0005
Ool00`00Oomoo`0?Ool00`00Oomoo`0lOol00`00Oomoo`0nOol00`00Oomoo`0lOol00`00Oomoo`0m
Ool00`00Oomoo`0fOol00`00Oomoo`05Ool000]oo`@002Ioo`8000Ioo`03001oogoo011oo`03001o
ogoo03]oo`03001oogoo03ioo`03001oogoo03aoo`03001oogoo03ioo`03001oogoo03Eoo`03001o
ogoo00Eoo`002goo00@007ooOol002ioo`03001oogoo011oo`03001oogoo03]oo`03001oogoo03mo
o`03001oogoo03]oo`03001oogoo03ioo`03001oogoo03Eoo`03001oogoo00Eoo`002goo00@007oo
Ool002ioo`<0011oo`03001oogoo03]oo`03001oogoo03moo`03001oogoo03Yoo`03001oogoo03mo
o`03001oogoo03=oo`<000Moo`00?Goo00<007ooOol047oo00<007ooOol0>Woo00<007ooOol0@7oo
00<007ooOol0>Woo00<007ooOol0?goo00<007ooOol0=Goo00<007ooOol01Goo000mOol00`00Oomo
o`0AOol00`00Oomoo`0iOol00`00Oomoo`10Ool00`00Oomoo`0jOol00`00Oomoo`10Ool00`00Oomo
o`0dOol00`00Oomoo`05Ool003eoo`03001oogoo015oo`03001oogoo03Uoo`03001oogoo041oo`03
001oogoo03Yoo`03001oogoo041oo`03001oogoo03Aoo`03001oogoo00Eoo`00?Goo00<007ooOol0
4Goo00<007ooOol0>Goo00<007ooOol0@Goo00<007ooOol0>Goo00<007ooOol0@7oo00<007ooOol0
=7oo00<007ooOol01Goo000mOol3000AOol00`00Oomoo`0iOol00`00Oomoo`11Ool00`00Oomoo`0h
Ool00`00Oomoo`11Ool00`00Oomoo`0bOol30007Ool003eoo`03001oogoo015oo`03001oogoo03Qo
o`03001oogoo049oo`03001oogoo03Qoo`03001oogoo045oo`03001oogoo03Aoo`03001oogoo00Eo
o`00?Goo00<007ooOol04Woo00<007ooOol0=goo00<007ooOol0@Woo00<007ooOol0>7oo00<007oo
Ool0@Woo00<007ooOol0<goo00<007ooOol01Goo000mOol00`00Oomoo`0BOol00`00Oomoo`0gOol0
0`00Oomoo`12Ool00`00Oomoo`0hOol00`00Oomoo`12Ool00`00Oomoo`0cOol00`00Oomoo`05Ool0
00Uoo`03001oogoo009oo`03001oogoo02aoo`03001oogoo019oo`03001oogoo03Moo`03001oogoo
04=oo`03001oogoo03Moo`03001oogoo049oo`03001oogoo03=oo`03001oogoo00Eoo`002Goo1P00
;Woo0`004Woo00<007ooOol0=goo00<007ooOol0@goo00<007ooOol0=Woo00<007ooOol0@goo00<0
07ooOol0<Goo0`001goo000>Ool00`00Oomoo`0/Ool00`00Oomoo`0BOol00`00Oomoo`0gOol00`00
Oomoo`13Ool00`00Oomoo`0fOol00`00Oomoo`13Ool00`00Oomoo`0cOol00`00Oomoo`05Ool003eo
o`03001oogoo01=oo`03001oogoo03Eoo`03001oogoo04Aoo`03001oogoo03Ioo`03001oogoo04Ao
o`03001oogoo039oo`03001oogoo00Eoo`00?Goo00<007ooOol04goo00<007ooOol0=Goo00<007oo
Ool0A7oo00<007ooOol0=Woo00<007ooOol0A7oo00<007ooOol0<Woo00<007ooOol01Goo000mOol0
0`00Oomoo`0COol00`00Oomoo`0eOol00`00Oomoo`15Ool00`00Oomoo`0eOol00`00Oomoo`14Ool0
0`00Oomoo`0bOol00`00Oomoo`05Ool000aoo`8002moo`<001=oo`03001oogoo03Eoo`03001oogoo
04Eoo`03001oogoo03Aoo`03001oogoo04Eoo`03001oogoo031oo`<000Moo`002goo0P0000=oo`00
Ool0;Goo00<007ooOol057oo00<007ooOol0=7oo00<007ooOol0AGoo00<007ooOol0=7oo00<007oo
Ool0AWoo00<007ooOol0<Goo00<007ooOol01Goo000;Ool200000goo001oo`0]Ool00`00Oomoo`0D
Ool00`00Oomoo`0cOol00`00Oomoo`16Ool00`00Oomoo`0dOol00`00Oomoo`16Ool00`00Oomoo`0a
Ool00`00Oomoo`05Ool000aoo`03001oo`0002ioo`03001oogoo01Aoo`03001oogoo03=oo`03001o
ogoo04Ioo`03001oogoo03Aoo`03001oogoo04Ioo`03001oogoo035oo`03001oogoo00Eoo`007Goo
0P0017oo0P0017oo0P000goo10000goo0P001Woo00<007ooOol057oo00<007ooOol0<goo00<007oo
Ool0Agoo00<007ooOol0<Woo00<007ooOol0Agoo00<007ooOol0<Goo00<007ooOol01Goo000;Ool0
0`00Oomoo`0>Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0005
Ool00`00Oomoo`0DOol00`00Oomoo`0cOol00`00Oomoo`17Ool00`00Oomoo`0bOol00`00Oomoo`17
Ool00`00Oomoo`0aOol00`00Oomoo`05Ool000]oo`8000moo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol01Goo00<007ooOol00goo0`005Goo00<007ooOol0<Woo00<007ooOol0Agoo00<0
07ooOol0<Woo00<007ooOol0B7oo00<007ooOol0;Woo0`001goo000=Ool2000=Ool01000Oomoo`00
27oo00@007ooOol000Aoo`03001oogoo009oo`8000Ioo`03001oogoo01Eoo`03001oogoo035oo`03
001oogoo04Qoo`03001oogoo039oo`03001oogoo04Qoo`03001oogoo031oo`03001oogoo00Eoo`00
3Goo0P003Goo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol01Goo
00<007ooOol05Goo00<007ooOol0<Goo00<007ooOol0B7oo00<007ooOol0<Woo00<007ooOol0B7oo
00<007ooOol0<7oo00<007ooOol01Goo000;Ool2000@Ool2000:Ool20004Ool20004Ool30005Ool0
0`00Oomoo`0EOol00`00Oomoo`0aOol00`00Oomoo`19Ool00`00Oomoo`0`Ool00`00Oomoo`19Ool0
0`00Oomoo`0`Ool00`00Oomoo`05Ool000]oo`03001oogoo02moo`03001oogoo01Ioo`03001oogoo
031oo`03001oogoo04Uoo`03001oogoo031oo`03001oogoo04Uoo`03001oogoo031oo`03001oogoo
00Eoo`00?Goo0`005Woo00<007ooOol0<7oo00<007ooOol0BGoo00<007ooOol0<7oo00<007ooOol0
BWoo00<007ooOol0;Goo0`001goo000<Ool2000_Ool00`00Oomoo`0FOol00`00Oomoo`0_Ool00`00
Oomoo`1:Ool00`00Oomoo`0`Ool00`00Oomoo`1:Ool00`00Oomoo`0_Ool00`00Oomoo`05Ool000]o
o`800003Ool007oo02eoo`03001oogoo01Ioo`03001oogoo02moo`03001oogoo04]oo`03001oogoo
02moo`03001oogoo04Yoo`03001oogoo02moo`03001oogoo00Eoo`002goo0P0000=oo`00Ool0;Goo
00<007ooOol05goo00<007ooOol0;Woo00<007ooOol0Bgoo00<007ooOol0;Woo00<007ooOol0Bgoo
00<007ooOol0;goo00<007ooOol01Goo000<Ool00`00Ool0000^Ool00`00Oomoo`0GOol00`00Oomo
o`0^Ool00`00Oomoo`1;Ool00`00Oomoo`0^Ool00`00Oomoo`1<Ool00`00Oomoo`0^Ool00`00Oomo
o`05Ool003eoo`<001Moo`03001oogoo02ioo`03001oogoo04]oo`03001oogoo02ioo`03001oogoo
04aoo`03001oogoo02aoo`<000Moo`00?Goo00<007ooOol05goo00<007ooOol0;Goo00<007ooOol0
C7oo00<007ooOol0;Woo00<007ooOol0C7oo00<007ooOol0;Woo00<007ooOol01Goo0009Ool00`00
Oomoo`02Ool00`00Oomoo`0/Ool00`00Oomoo`0GOol00`00Oomoo`0]Ool00`00Oomoo`1=Ool00`00
Oomoo`0/Ool00`00Oomoo`1=Ool00`00Oomoo`0^Ool00`00Oomoo`05Ool000Uoo`H002ioo`03001o
ogoo01Qoo`03001oogoo02aoo`03001oogoo04eoo`03001oogoo02aoo`03001oogoo04eoo`03001o
ogoo02ioo`03001oogoo00Eoo`003Woo00<007ooOol0;7oo00<007ooOol067oo00<007ooOol0;7oo
00<007ooOol0CGoo00<007ooOol0;7oo00<007ooOol0CWoo00<007ooOol0;Goo00<007ooOol01Goo
000mOol3000HOol00`00Oomoo`0/Ool00`00Oomoo`1=Ool00`00Oomoo`0/Ool00`00Oomoo`1>Ool0
0`00Oomoo`0[Ool30007Ool003eoo`03001oogoo01Qoo`03001oogoo02]oo`03001oogoo04moo`03
001oogoo02Yoo`03001oogoo04moo`03001oogoo02eoo`03001oogoo00Eoo`00?Goo00<007ooOol0
6Goo00<007ooOol0:Woo00<007ooOol0Cgoo00<007ooOol0:Woo00<007ooOol0Cgoo00<007ooOol0
;Goo00<007ooOol01Goo000mOol00`00Oomoo`0IOol00`00Oomoo`0ZOol00`00Oomoo`1?Ool00`00
Oomoo`0ZOol00`00Oomoo`1?Ool00`00Oomoo`0]Ool00`00Oomoo`05Ool000]oo`@002ioo`03001o
ogoo01Uoo`03001oogoo02Yoo`03001oogoo04moo`03001oogoo02Yoo`03001oogoo051oo`03001o
ogoo02aoo`03001oogoo00Eoo`002Woo00<007ooOol00Woo00<007ooOol0:goo0`006Goo00<007oo
Ool0:Woo00<007ooOol0D7oo00<007ooOol0:7oo00<007ooOol0DGoo00<007ooOol0:Woo0`001goo
0009Ool00`00Oomoo`04Ool00`00Oomoo`0ZOol00`00Oomoo`0IOol00`00Oomoo`0YOol00`00Oomo
o`1AOol00`00Oomoo`0XOol00`00Oomoo`1AOol00`00Oomoo`0/Ool00`00Oomoo`05Ool003eoo`03
001oogoo01Yoo`03001oogoo02Qoo`03001oogoo055oo`03001oogoo02Qoo`03001oogoo055oo`03
001oogoo02aoo`03001oogoo00Eoo`002goo00@007ooOol001Aoo`8000Aoo`8000Aoo`8000Aoo`80
00Ioo`03001oogoo01Yoo`03001oogoo02Qoo`03001oogoo055oo`03001oogoo02Qoo`03001oogoo
059oo`03001oogoo02]oo`03001oogoo00Eoo`002goo10004goo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`001Goo00<007ooOol06Woo00<007ooOol0:7oo00<007ooOol0DGoo00<007oo
Ool0:7oo00<007ooOol0DWoo00<007ooOol0:goo00<007ooOol01Goo000;Ool00`00Oomoo`0DOol0
1000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo00=oo`<001Yoo`03001oogoo02Moo`03001o
ogoo05=oo`03001oogoo02Ioo`03001oogoo05=oo`03001oogoo02Uoo`<000Moo`0037oo0`004goo
00@007ooOol000Qoo`04001oogoo0003Ool20006Ool00`00Oomoo`0JOol00`00Oomoo`0WOol00`00
Oomoo`1COol00`00Oomoo`0VOol00`00Oomoo`1COol00`00Oomoo`0[Ool00`00Oomoo`05Ool000]o
o`03001oogoo01Aoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0
6goo00<007ooOol09Woo00<007ooOol0Dgoo00<007ooOol09Woo00<007ooOol0E7oo00<007ooOol0
:Woo00<007ooOol01Goo000<Ool3000DOol2000:Ool20004Ool30005Ool00`00Oomoo`0KOol00`00
Oomoo`0VOol00`00Oomoo`1COol00`00Oomoo`0VOol00`00Oomoo`1DOol00`00Oomoo`0ZOol00`00
Oomoo`05Ool003eoo`03001oogoo01]oo`03001oogoo02Eoo`03001oogoo05Eoo`03001oogoo02Ao
o`03001oogoo05Eoo`03001oogoo02Yoo`03001oogoo00Eoo`002Goo00<007ooOol017oo00<007oo
Ool0:Woo0`006goo00<007ooOol09Goo00<007ooOol0EGoo00<007ooOol097oo00<007ooOol0EGoo
00<007ooOol0:7oo0`001goo000:Ool00`00Oomoo`02Ool00`00Oomoo`0[Ool00`00Oomoo`0KOol0
0`00Oomoo`0UOol00`00Oomoo`1EOol00`00Oomoo`0TOol00`00Oomoo`1FOol00`00Oomoo`0YOol0
0`00Oomoo`05Ool000]oo`@002ioo`03001oogoo01aoo`03001oogoo02Aoo`03001oogoo05Eoo`03
001oogoo02Aoo`03001oogoo05Ioo`03001oogoo02Uoo`03001oogoo00Eoo`00?Goo00<007ooOol0
77oo00<007ooOol08goo00<007ooOol0EWoo00<007ooOol08goo00<007ooOol0Egoo00<007ooOol0
:Goo00<007ooOol01Goo000mOol00`00Oomoo`0LOol00`00Oomoo`0SOol00`00Oomoo`1GOol00`00
Oomoo`0ROol00`00Oomoo`1GOol00`00Oomoo`0YOol00`00Oomoo`05Ool003eoo`<001aoo`03001o
ogoo02=oo`03001oogoo05Moo`03001oogoo029oo`03001oogoo05Qoo`03001oogoo02Ioo`<000Mo
o`00?Goo00<007ooOol07Goo00<007ooOol08Woo00<007ooOol0Egoo00<007ooOol08Woo00<007oo
Ool0F7oo00<007ooOol0:7oo00<007ooOol01Goo000mOol00`00Oomoo`0MOol00`00Oomoo`0QOol0
0`00Oomoo`1HOol00`00Oomoo`0QOol00`00Oomoo`1IOol00`00Oomoo`0XOol00`00Oomoo`05Ool0
03eoo`03001oogoo01eoo`03001oogoo025oo`03001oogoo05Uoo`03001oogoo021oo`03001oogoo
05Uoo`03001oogoo02Qoo`03001oogoo00Eoo`00?Goo00<007ooOol07Goo00<007ooOol08Goo00<0
07ooOol0FGoo00<007ooOol087oo00<007ooOol0FWoo00<007ooOol09goo00<007ooOol01Goo000m
Ool3000NOol00`00Oomoo`0POol00`00Oomoo`1IOol00`00Oomoo`0POol00`00Oomoo`1JOol00`00
Oomoo`0UOol30007Ool003eoo`03001oogoo01ioo`03001oogoo01moo`03001oogoo05Yoo`03001o
ogoo01moo`03001oogoo05]oo`03001oogoo02Moo`03001oogoo00Eoo`00?Goo00<007ooOol07Woo
00<007ooOol07goo00<007ooOol0Fgoo00<007ooOol07Woo00<007ooOol0Fgoo00<007ooOol09goo
00<007ooOol01Goo000mOol00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`1KOol00`00Oomo
o`0NOol00`00Oomoo`1LOol00`00Oomoo`0NOol00`00Oomoo`05Ool00`00Oomoo`05Ool003eoo`03
001oogoo01moo`03001oogoo01ioo`03001oogoo05]oo`03001oogoo01ioo`03001oogoo05aoo`03
001oogoo01ioo`03001oogoo00Eoo`03001oogoo00Eoo`00?Goo0`007goo00<007ooOol07Goo00<0
07ooOol0GGoo00<007ooOol077oo00<007ooOol0GGoo00<007ooOol07Goo00<007ooOol017oo0`00
1goo000mOol00`00Oomoo`0OOol00`00Oomoo`0MOol00`00Oomoo`1MOol00`00Oomoo`0LOol00`00
Oomoo`1MOol00`00Oomoo`0MOol00`00Oomoo`06Ool00`00Oomoo`05Ool003eoo`03001oogoo021o
o`03001oogoo01aoo`03001oogoo05eoo`03001oogoo01aoo`03001oogoo05ioo`03001oogoo01ao
o`03001oogoo00Ioo`03001oogoo00Eoo`007Goo0P0017oo0P0017oo0P001Goo00<007ooOol00Woo
0P001Woo00<007ooOol087oo00<007ooOol06goo00<007ooOol0GWoo00<007ooOol06goo00<007oo
Ool0Ggoo00<007ooOol077oo00<007ooOol01Woo00<007ooOol01Goo000LOol01000Oomoo`0027oo
00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`0POol00`00Oomo
o`0KOol00`00Oomoo`1OOol00`00Oomoo`0JOol00`00Oomoo`1OOol00`00Oomoo`0KOol00`00Oomo
o`07Ool00`00Oomoo`05Ool001aoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol017oo
00<007ooOol00goo0`008Goo00<007ooOol06Goo00<007ooOol0H7oo00<007ooOol06Woo00<007oo
Ool0Ggoo00<007ooOol06goo00<007ooOol01Goo0`001goo000LOol01000Oomoo`0027oo00@007oo
Ool000Eoo`04001oogooOol20006Ool00`00Oomoo`0QOol00`00Oomoo`0IOol00`00Oomoo`1POol0
0`00Oomoo`0JOol00`00Oomoo`1POol00`00Oomoo`0JOol00`00Oomoo`07Ool00`00Oomoo`05Ool0
01aoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`03001o
ogoo025oo`03001oogoo01Uoo`03001oogoo061oo`03001oogoo01Uoo`03001oogoo065oo`03001o
ogoo01Uoo`03001oogoo00Qoo`03001oogoo00Eoo`007Goo0P002Woo0P000goo10000goo0`001Goo
00<007ooOol08Goo00<007ooOol067oo00<007ooOol0HWoo00<007ooOol067oo00<007ooOol0HGoo
00<007ooOol06Goo00<007ooOol027oo00<007ooOol01Goo000mOol00`00Oomoo`0ROol00`00Oomo
o`0GOol00`00Oomoo`1ROol00`00Oomoo`0HOol00`00Oomoo`1QOol00`00Oomoo`0IOol00`00Oomo
o`08Ool00`00Oomoo`05Ool003eoo`<0029oo`03001oogoo01Moo`03001oogoo069oo`03001oogoo
01Qoo`03001oogoo069oo`03001oogoo01Moo`03001oogoo00Moo`<000Moo`00?Goo00<007ooOol0
8Woo00<007ooOol05Woo00<007ooOol0I7oo00<007ooOol05Woo00<007ooOol0Hgoo00<007ooOol0
5goo00<007ooOol02Goo00<007ooOol01Goo000mOol00`00Oomoo`0ROol00`00Oomoo`0FOol00`00
Oomoo`1TOol00`00Oomoo`0FOol00`00Oomoo`1SOol00`00Oomoo`0FOol00`00Oomoo`0:Ool00`00
Oomoo`05Ool003eoo`03001oogoo02=oo`03001oogoo01Eoo`03001oogoo06Aoo`03001oogoo01Io
o`03001oogoo06Aoo`03001oogoo01Eoo`03001oogoo00Yoo`03001oogoo00Eoo`00?Goo00<007oo
Ool08goo00<007ooOol057oo00<007ooOol0IWoo00<007ooOol057oo00<007ooOol0IGoo00<007oo
Ool05Goo00<007ooOol02Woo00<007ooOol01Goo000mOol00`00Oomoo`0SOol00`00Oomoo`0DOol0
0`00Oomoo`1VOol00`00Oomoo`0DOol00`00Oomoo`1UOol00`00Oomoo`0DOol00`00Oomoo`0;Ool0
0`00Oomoo`05Ool003eoo`<002Aoo`03001oogoo01=oo`03001oogoo06Moo`03001oogoo019oo`03
001oogoo06Moo`03001oogoo01=oo`03001oogoo00Uoo`<000Moo`00?Goo00<007ooOol097oo00<0
07ooOol04Woo00<007ooOol0J7oo00<007ooOol04Woo00<007ooOol0Igoo00<007ooOol04goo00<0
07ooOol02goo00<007ooOol01Goo000mOol00`00Oomoo`0UOol00`00Oomoo`0AOol00`00Oomoo`1X
Ool00`00Oomoo`0AOol00`00Oomoo`1YOol00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00Oomoo`05
Ool003eoo`03001oogoo02Eoo`03001oogoo011oo`03001oogoo06Yoo`03001oogoo011oo`03001o
ogoo06Uoo`03001oogoo015oo`03001oogoo00aoo`03001oogoo00Eoo`00?Goo00<007ooOol09Woo
00<007ooOol03goo00<007ooOol0JWoo00<007ooOol03goo00<007ooOol0Jgoo00<007ooOol03goo
00<007ooOol03Goo00<007ooOol01Goo000mOol3000VOol00`00Oomoo`0>Ool00`00Oomoo`1/Ool0
0`00Oomoo`0>Ool00`00Oomoo`1[Ool00`00Oomoo`0?Ool00`00Oomoo`0;Ool30007Ool003eoo`03
001oogoo02Moo`03001oogoo00eoo`03001oogoo06aoo`03001oogoo00ioo`03001oogoo06aoo`03
001oogoo00eoo`03001oogoo00ioo`03001oogoo00Eoo`00?Goo00<007ooOol09goo00<007ooOol0
37oo00<007ooOol0KWoo00<007ooOol037oo00<007ooOol0KWoo00<007ooOol037oo00<007ooOol0
3Woo00<007ooOol01Goo000mOol00`00Oomoo`0XOol00`00Oomoo`0;Ool00`00Oomoo`1_Ool00`00
Oomoo`0;Ool00`00Oomoo`1^Ool00`00Oomoo`0;Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool003eo
o`03001oogoo02Qoo`03001oogoo00Yoo`03001oogoo071oo`03001oogoo00Yoo`03001oogoo071o
o`03001oogoo00Yoo`03001oogoo00moo`03001oogoo00Eoo`00?Goo0`00:Goo00<007ooOol02Goo
00<007ooOol0LGoo00<007ooOol02Goo00<007ooOol0L7oo00<007ooOol02Goo00<007ooOol03Woo
0`001goo000mOol00`00Oomoo`0ZOol00`00Oomoo`07Ool00`00Oomoo`1bOol00`00Oomoo`08Ool0
0`00Oomoo`1bOol00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`05Ool003eoo`03001oogoo
02]oo`03001oogoo00Eoo`03001oogoo07Aoo`03001oogoo00Ioo`03001oogoo07Aoo`03001oogoo
00Ioo`03001oogoo015oo`03001oogoo00Eoo`00:Goo0P0017oo0P000goo1@0017oo00<007ooOol0
1Goo00<007ooOol08goo0P001Goo00<007ooOol017oo00<007ooOol0<Woo00<007ooOol0<Goo00<0
07ooOol01Woo0P0017oo0P008goo00<007ooOol0<Woo00<007ooOol07Goo00<007ooOol00goo0P00
37oo00<007ooOol01Goo00<007ooOol01Goo000XOol01000Oomoo`002Woo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Goo1P00
1Woo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol01goo1P001Goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007oo000010000goo00<007ooOol027oo
00<007ooOol01Goo00<007ooOol01Goo000XOol01000Oomoo`002Woo00<007ooOol017ooo`00C000
1goo000XOol01000Oomoo`002Woo00<007ooOol0ogooEgoo000XOol01000Oomoo`002Woo00<007oo
Ool0ogooEgoo000YOol2000:Ool2003oOomIOol00?mooi1oo`00ogooT7oo003oOon@Ool00?moo`Eo
o`<001]oo`<0039oo`<003Eoo`00ogoo27oo00<007ooOol06goo00<007ooOol0<7oo00<007ooOol0
=7oo001AOol20003Ool40003Ool20004Ool60002Ool20002Ool40002Ool00`00Ool00002Ool50002
Ool20004Ool30002Ool40008Ool40002Ool30004Ool40002Ool30003Ool20004Ool400000goo0000
00030002Ool20004Ool30003Ool20002Ool20002Ool20007Ool50002Ool20008Ool300000goo0000
0002Ool20002Ool20002Ool20002Ool30007Ool300000goo00000002Ool20002Ool20002Ool20002
Ool30009Ool300000goo0000000300001Goo00000000Ool00P001goo1@000Woo0`000Woo10000Woo
0`0017oo0P000goo10000goo0P008Woo001@Ool01000Oomoo`000goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`06001oo`00Ool007oo
10000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00=oo`03001o
ogoo009oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`@0
009oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Ioo`@0
009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Qo
o`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`0027oo100017oo00<007ooOol00Woo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`008Goo
001@Ool00`00Ool000020002Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`000Woo00D007oo001oo`0000Aoo`04001oogoo0005Ool40003Ool0
0`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol00goo
00<007ooOol00goo00@007ooOol000Eoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo00Uoo`04001oogoo000;Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`0027oo0`000goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`0027oo00<007ooOol00goo00<007ooOol00goo0`0037oo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`0ROol0051oo`03001oogoo00=oo`@000=oo`80009oo`800004Ool00000Ool40004Ool300001Goo
00000000Ool00P000Woo0`0000=oo`0000000`000goo0P000goo100027oo10000goo00@007ooOomo
o`800003Ool0000000=oo`<00003Ool0000000<00004Ool00000Ool20003Ool300000goo00000003
0003Ool20004Ool20002Ool4000:Ool300000goo000000030008Ool40003Ool20002Ool40004Ool4
0007Ool00`00Ool00004Ool20002Ool40004Ool40007Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Ool0000:Ool30003Ool20003Ool400000goo000000020004Ool20003Ool400000goo00000003
000QOol0051oo`03001oogoo01ioo`03001oogoo00aoo`03001oogoo01Ioo`03001oogoo00=oo`03
001oogoo00ioo`03001oogoo00moo`03001oogoo025oo`03001oogoo00Uoo`04001oogoo000JOol0
1000Oomoo`006Woo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo000/Ool00`00Oomoo`0R
Ool0055oo`<001aoo`8002Qoo`80009oo`8002Yoo`03001oogoo02Aoo`800004Ool00000000HOol3
00000goo0000000JOol3000017oo000000000goo0`0000=oo`0000003goo00<007ooOol0?Woo003o
Oon@Ool00?mooi1oo`00\
\>"],
  ImageRangeCache->{{{0, 398.438}, {245.875, 0}} -> {-6.66897, -0.125236, \
0.0956584, 0.00098272}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Reference\n",
  StyleBox["Jiao & Tang, 1999. An analytical solution of groundwater response \
to tidal fluctuation in a leaky confined aquifer, Water Resources Research, \
35(3), 747-751.", "Text"]
}], "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Time and Memory Info at End ", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Print[\ \ {{"\<Time used in Seconds:  \>", 
              NumberForm[TimeUsed[]]}, \ {"\<Memory Used in Mb: \>", 
              NumberForm[\(MemoryInUse[]/1024. \)/1024. ]}} // 
          TableForm];\)\)], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"Time used in Seconds:  \"\>", 
            TagBox[
              InterpretationBox["\<\"0.15\"\>",
                .15000000000000002,
                AutoDelete->True],
              NumberForm]},
          {"\<\"Memory Used in Mb: \"\>", 
            TagBox[
              InterpretationBox["\<\"2.18281\"\>",
                2.1828079223632813,
                AutoDelete->True],
              NumberForm]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Print"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{650, 595},
WindowMargins->{{29, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
CellLabelAutoDelete->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 156, 4, 169, "Title"],
Cell[1913, 57, 164, 6, 62, "Author"],

Cell[CellGroupData[{
Cell[2102, 67, 57, 1, 62, "Section"],

Cell[CellGroupData[{
Cell[2184, 72, 1553, 35, 210, "Input"],
Cell[3740, 109, 567, 10, 44, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4356, 125, 49, 0, 62, "Section"],

Cell[CellGroupData[{
Cell[4430, 129, 236, 4, 90, "Input"],
Cell[4669, 135, 663, 20, 37, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5381, 161, 62, 1, 62, "Section"],
Cell[5446, 164, 900, 17, 293, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6383, 186, 58, 1, 62, "Section"],

Cell[CellGroupData[{
Cell[6466, 191, 504, 9, 150, "Input"],
Cell[6973, 202, 47683, 1321, 255, 14445, 906, "GraphicsData", "PostScript", \
"Graphics"],
Cell[54659, 1525, 130, 3, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[54816, 1532, 264, 6, 108, "Section"],

Cell[CellGroupData[{
Cell[55105, 1542, 80, 1, 62, "Section"],

Cell[CellGroupData[{
Cell[55210, 1547, 269, 5, 90, "Input"],
Cell[55482, 1554, 665, 20, 37, "Print"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

